@@ -3,15 +3,14 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
-# set options to limit threads used by imported libraries
-options(cores=2)
-options(mc.cores=2)
 # xgboost uses data.table
 data.table::setDTthreads(2)
+RhpcBLASctl::blas_set_num_threads(2)
+RhpcBLASctl::omp_set_num_threads(2)
 
 ## -----------------------------------------------------------------------------
 library(tidysdm)
-lacerta_thin <- readRDS(system.file("extdata/lacerta_climate_sf.RDS",
+lacerta_thin <- readRDS(system.file("extdata/lacerta_thin_all_vars.rds",
   package = "tidysdm"
 ))
 lacerta_thin$bio05[37] <- NA
@@ -41,6 +40,7 @@ lacerta_models <-
   option_add(control = control_ensemble_grid())
 
 ## ----error=TRUE---------------------------------------------------------------
+try({
 set.seed(100)
 lacerta_cv <- spatial_block_cv(lacerta_thin, v = 5)
 lacerta_models <-
@@ -49,13 +49,14 @@ lacerta_models <-
     resamples = lacerta_cv, grid = 3,
     metrics = sdm_metric_set(), verbose = TRUE
   )
+})
 
 ## -----------------------------------------------------------------------------
 lacerta_prep <- lacerta_rec %>% prep(lacerta_thin)
 lacerta_prep
 
 ## -----------------------------------------------------------------------------
-lacerta_thin <- readRDS(system.file("extdata/lacerta_climate_sf.RDS",
+lacerta_thin <- readRDS(system.file("extdata/lacerta_thin_all_vars.rds",
   package = "tidysdm"
 ))
 suggested_vars <- c("bio05", "bio06", "bio13", "bio14", "bio15")
@@ -63,6 +64,7 @@ lacerta_rec_sel <- recipe(lacerta_thin, formula = class ~ .) %>%
   step_select(all_of(suggested_vars))
 
 ## ----error=TRUE---------------------------------------------------------------
+try({
 lacerta_models <-
   # create the workflow_set
   workflow_set(
@@ -87,13 +89,14 @@ lacerta_models <-
     resamples = lacerta_cv, grid = 3,
     metrics = sdm_metric_set(), verbose = TRUE
   )
+})
 
 ## -----------------------------------------------------------------------------
 lacerta_prep_sel <- lacerta_rec_sel %>% prep(lacerta_thin)
 lacerta_prep_sel
 
 ## -----------------------------------------------------------------------------
-lacerta_thin <- readRDS(system.file("extdata/lacerta_climate_sf.RDS",
+lacerta_thin <- readRDS(system.file("extdata/lacerta_thin_all_vars.rds",
   package = "tidysdm"
 ))
 
@@ -136,12 +139,12 @@ lacerta_models <-
   )
 
 ## -----------------------------------------------------------------------------
-lacerta_thin <- readRDS(system.file("extdata/lacerta_climate_sf.RDS",
+lacerta_thin <- readRDS(system.file("extdata/lacerta_thin_all_vars.rds",
   package = "tidysdm"
 ))
 set.seed(123)
 lacerta_thin <- lacerta_thin[sample(
-  1:nrow(lacerta_thin),
+  seq_len(nrow(lacerta_thin)),
   nrow(lacerta_thin) / 5
 ), ]
 
